@@ -1227,7 +1227,7 @@ static void ordinal_ppmx(
       	  	      lgconN = lgconN + lgcont;
       	  	  	}
       	  	  	if(*consim==2){
-      	  	      lgcont = gsimconNNIG(m0, k0, nu0, s20, sumx2tmp, sumx2[k], mnmle[p], s2mle[p], nh[k], 0, 0, 1);
+      	  	      lgcont = gsimconNNIG(m0, k0, nu0, s20, sumx2tmp, sumx2tmp, mnmle[p], s2mle[p], nh[k], 0, 0, 1);
       	  	      lgconN = lgconN + lgcont;
       	  	  	}
       	  	  }
